@@ -1,6 +1,6 @@
 /* mbsupport.h --- Localize determination of whether we have multibyte stuff.
 
-   Copyright (C) 2004-2005, 2007, 2009-2010 Free Software Foundation, Inc.
+   Copyright (C) 2004-2005, 2007, 2009-2011 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -26,12 +26,10 @@
    The tests should be *all* the ones that are needed for an individual
    application.  */
 
-#ifdef HAVE_STDLIB_H
 #include <stdlib.h>
-#endif
 
-#if defined(HAVE_WCSCOLL) && defined(HAVE_ISWCTYPE)
+#if defined HAVE_WCSCOLL && defined HAVE_ISWCTYPE
 # define MBS_SUPPORT 1
 #else
-# undef MBS_SUPPORT
+# define MBS_SUPPORT 0
 #endif
