@@ -1,5 +1,5 @@
 /* search.c - searching subroutines using dfa, kwset and regex for grep.
-   Copyright 1992, 1998, 2000, 2007, 2009-2010 Free Software Foundation, Inc.
+   Copyright 1992, 1998, 2000, 2007, 2009-2011 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -24,38 +24,35 @@
 #include <sys/types.h>
 
 #include "mbsupport.h"
-#ifdef MBS_SUPPORT
-/* We can handle multibyte strings. */
-# include <wchar.h>
-# include <wctype.h>
-#endif
 
+#include <wchar.h>
+#include <wctype.h>
 #include <regex.h>
+
 #include "system.h"
-#include "grep.h"
 #include "error.h"
+#include "grep.h"
 #include "kwset.h"
 #include "xalloc.h"
 
 /* searchutils.c */
-void kwsinit (kwset_t *);
+extern void kwsinit (kwset_t *);
 
-#ifdef MBS_SUPPORT
-char * mbtolower (const char *, size_t *);
-bool is_mb_middle(const char **, const char *, const char *, size_t);
+#if MBS_SUPPORT
+extern char *mbtolower (const char *, size_t *);
+extern bool is_mb_middle (const char **, const char *, const char *, size_t);
 #endif
 
 /* dfasearch.c */
-void GEAcompile (char const *, size_t, reg_syntax_t);
-size_t EGexecute (char const *, size_t, size_t *, char const *);
+extern void GEAcompile (char const *, size_t, reg_syntax_t);
+extern size_t EGexecute (char const *, size_t, size_t *, char const *);
 
 /* kwsearch.c */
-void Fcompile (char const *, size_t);
-size_t Fexecute (char const *, size_t, size_t *, char const *);
+extern void Fcompile (char const *, size_t);
+extern size_t Fexecute (char const *, size_t, size_t *, char const *);
 
 /* pcresearch.c */
-void Pcompile (char const *, size_t);
-size_t Pexecute (char const *, size_t, size_t *, char const *);
-
+extern void Pcompile (char const *, size_t);
+extern size_t Pexecute (char const *, size_t, size_t *, char const *);
 
 #endif /* GREP_SEARCH_H */
